@@ -184,18 +184,18 @@ class MarketStats:
         all_stats.update(dict(zip(['past_buy_trend_unit4', 'past_sell_trend_unit4'], past_trend_unit4)))
         all_stats.update(dict(zip(['past_buy_trend_unit5', 'past_sell_trend_unit5'], past_trend_unit5)))
         all_stats.update(dict(zip(['present_buy_trend', 'present_sell_trend'], present_trend)))
-        all_stats.update(dict(zip(['mean_buy_trend', 'mean_sell_trend'], self.mean_trend(past_trend_unit1, present_trend))))
-        all_stats.update(dict(zip(['mean_buy_trend_unit1', 'mean_sell_trend_unit1'], self.mean_trend(past_trend_unit1, present_trend))))
-        all_stats.update(dict(zip(['mean_buy_trend_unit2', 'mean_sell_trend_unit2'], self.mean_trend(past_trend_unit2, present_trend))))
-        all_stats.update(dict(zip(['mean_buy_trend_unit3', 'mean_sell_trend_unit3'], self.mean_trend(past_trend_unit3, present_trend))))
-        all_stats.update(dict(zip(['mean_buy_trend_unit4', 'mean_sell_trend_unit4'], self.mean_trend(past_trend_unit4, present_trend))))
-        all_stats.update(dict(zip(['mean_buy_trend_unit5', 'mean_sell_trend_unit5'], self.mean_trend(past_trend_unit5, present_trend))))
-        all_stats.update(dict(zip(['past_buy_target_unit1', 'past_sell_target_unit1'], past_targets_unit1)
-        all_stats.update(dict(zip(['past_buy_target_unit2', 'past_sell_target_unit2'], past_targets_unit2)
-        all_stats.update(dict(zip(['past_buy_target_unit3', 'past_sell_target_unit3'], past_targets_unit3)
-        all_stats.update(dict(zip(['past_buy_target_unit4', 'past_sell_target_unit4'], past_targets_unit4)
-        all_stats.update(dict(zip(['past_buy_target_unit5', 'past_sell_target_unit5'], past_targets_unit5)
-        all_stats.update(dict(zip(['present_buy_target', 'present_buy_target'], present_targets)
+        all_stats.update(dict(zip(['mean_buy_trend', 'mean_sell_trend'], self.calculate_mean_trend(past_trend_unit1, present_trend))))
+        all_stats.update(dict(zip(['mean_buy_trend_unit1', 'mean_sell_trend_unit1'], self.calculate_mean_trend(past_trend_unit1, present_trend))))
+        all_stats.update(dict(zip(['mean_buy_trend_unit2', 'mean_sell_trend_unit2'], self.calculate_mean_trend(past_trend_unit2, present_trend))))
+        all_stats.update(dict(zip(['mean_buy_trend_unit3', 'mean_sell_trend_unit3'], self.calculate_mean_trend(past_trend_unit3, present_trend))))
+        all_stats.update(dict(zip(['mean_buy_trend_unit4', 'mean_sell_trend_unit4'], self.calculate_mean_trend(past_trend_unit4, present_trend))))
+        all_stats.update(dict(zip(['mean_buy_trend_unit5', 'mean_sell_trend_unit5'], self.calculate_mean_trend(past_trend_unit5, present_trend))))
+        all_stats.update(dict(zip(['past_buy_target_unit1', 'past_sell_target_unit1'], past_targets_unit1)))
+        all_stats.update(dict(zip(['past_buy_target_unit2', 'past_sell_target_unit2'], past_targets_unit2)))
+        all_stats.update(dict(zip(['past_buy_target_unit3', 'past_sell_target_unit3'], past_targets_unit3)))
+        all_stats.update(dict(zip(['past_buy_target_unit4', 'past_sell_target_unit4'], past_targets_unit4)))
+        all_stats.update(dict(zip(['past_buy_target_unit5', 'past_sell_target_unit5'], past_targets_unit5)))
+        all_stats.update(dict(zip(['present_buy_target', 'present_buy_target'], present_targets)))
         all_stats.update(dict(zip(['volume_buy_trend', 'volume_sell_trend'], volume_trend)))
         all_stats.update({"orderbook_timestamp": orderbook_timestamp})
         all_stats.update({"price_weighted_unit1": self.price_weighted(units=1)})
